/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ranger.plugin.model;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility;
import com.fasterxml.jackson.annotation.JsonInclude;

@JsonAutoDetect(getterVisibility = Visibility.NONE, setterVisibility = Visibility.NONE, fieldVisibility = Visibility.ANY)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
public class RangerSecurityZoneHeaderInfo extends RangerBaseModelObject implements java.io.Serializable {
    private static final long serialVersionUID = 1L;
    private String            name;

    public RangerSecurityZoneHeaderInfo() {
        super();
        setId(-1L);
        setName("");
    }

    public RangerSecurityZoneHeaderInfo(Long id, String name) {
        super();
        setId(id);
        setName(name);
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public StringBuilder toString(StringBuilder sb) {
        sb.append("id={").append(getId()).append("} ");
        sb.append("name={").append(name).append("} ");
        sb.append("isEnabled={").append(getIsEnabled()).append("} ");
        return sb;
    }
}
